@@ -2,6 +2,8 @@
     The Auction class represents an auction on a Board.
 """
 
+from typing import Dict, List, Union
+
 __all__ = ['Auction']
 
 from .call import Call
@@ -25,7 +27,7 @@ class Auction(object):
         First call for the auction (Generally implemented by a rich PBN file)
     """
 
-    def __init__(self, calls=None, first_caller=None):
+    def __init__(self, calls: Union[List[Call], None]=None, first_caller: str=''):
         """Create an auction with the given calls and first_caller."""
         self.first_caller = first_caller
         if not calls:
@@ -35,24 +37,24 @@ class Auction(object):
             if isinstance(call, str):
                 call = Call(call)
             self._calls.append(call)
-        self._note_keys = []
-        self._notes = {}
+        self._note_keys: List[str] = []
+        self._notes: Dict[str, str] = {}
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Return the repr string for the object."""
         return f'Auction: {self._get_call_names()}'
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return the str string for the object."""
         return f'Auction: {self._get_call_names()}'
 
-    def _get_call_names(self):
+    def _get_call_names(self) -> str:
         """Return call names as a string."""
         call_names = [call.name for call in self._calls]
         return ', '.join(call_names)
 
     @property
-    def first_caller(self):
+    def first_caller(self) -> Union[str, None]:
         """Return the first_caller value."""
         return self._first_caller
 
@@ -67,7 +69,7 @@ class Auction(object):
         self._first_caller = value
 
     @property
-    def calls(self):
+    def calls(self)-> List[Call]:
         """Return the calls list."""
         return self._calls
 
@@ -87,7 +89,7 @@ class Auction(object):
             self._calls.append(call)
 
     @property
-    def note_keys(self):
+    def note_keys(self) -> List[str]:
         """Return the note_keys list."""
         return self._note_keys
 
@@ -103,7 +105,7 @@ class Auction(object):
             self._note_keys.append(key)
 
     @property
-    def notes(self):
+    def notes(self) -> Dict[str, str]:
         """Return the notes dict."""
         return self._notes
 
@@ -113,4 +115,3 @@ class Auction(object):
         if not isinstance(value, dict):
             raise TypeError('Notes must be a dict')
         self._note_keys = value
-
