@@ -49,8 +49,10 @@ class Contract(object):
             self._call = Call('')
         if self._name:
             self._level = int(self._name[0])
+            self._target_tricks = self._level + 6
         else:
             self._level = 0
+            self._target_tricks = 0
         self._modifier  = ''
 
     def __repr__(self) -> str:
@@ -151,13 +153,18 @@ class Contract(object):
         return self._modifier
 
     @modifier.setter
-    def modifier(self, value: str):  # TODO tests for modifier
+    def modifier(self, value: str):
         """Set contract's modifier (i.e.: '', 'D' or 'R')."""
         if value in ['D', 'R']:
             self._modifier = value
         else:
             self._modifier = ''
 
+    @property
+    def target_tricks(self) -> int:
+        """Return the number of tricks needed to make the contract."""
+        return self._target_tricks
+
     @staticmethod
     def _is_valid(name: str) -> bool:
         """Return True if the contact name is valid."""
@@ -213,4 +220,4 @@ class Contract(object):
         for call in calls:
             if not call.is_pass:
                 return False
-        return True
\ No newline at end of file
+        return True
