@@ -122,6 +122,7 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
     event = Event()
     board = Board()
     value = ''
+
     for line in file_lines:
         if line:
             tag = ""
@@ -263,17 +264,19 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
                     # board.tricks[trick_index] = trick
                     board.tricks.append(trick)
                     trick_index += 1
+
     return events
 
 
 def _parse_pbn_line(line: str) -> Tuple[str, str]:
     """Return the tag and value from a pbn text line."""
     # example pbn line: [Site "Amsterdam, The Netherlands NLD"]
-    space_at = line.find(" ")
+    line = line.strip()
+    space_at = line.find(' ')
     tag = line[1:space_at]
     value = line[space_at + 1:]
     value = value[:-1]
-    value = value.replace('"', "")
+    value = value.replace('"', '')
     return (tag, value)
 
 
@@ -368,7 +371,6 @@ def _parse_pbn_play_section(board: Board, tag: str, value: str, line: str, first
             trick.note_keys = [key for key in trick_note_keys]
     return trick
 
-
 def _get_pbn_dealer_index(board: Board, deal: str) -> int:
     """
         Return the first hand index to ensure that the first hand
