@@ -769,8 +769,9 @@ class Hand(object):
         """Return the sortest suit in the hand."""
         long_suits = [self._longest_suit, self._second_suit, self._third_suit]
         suits = [Suit(suit) for suit in SUITS]
-        for index, suit in enumerate(long_suits):
-            suits.remove(suit)
+        for suit in long_suits:
+            if suit in suits:
+                suits.remove(suit)
         return suits[0]
 
     def _get_distribution_points(self):
