@@ -105,4 +105,13 @@ class Trick(object):
     @property
     def start_suit(self) -> Union[Suit, None]:
         """Return the Suit of the lead card in the trick."""
+        if not self._start_suit and self._cards:
+            self._start_suit = self.cards[0].suit
+        return self._start_suit
+
+    @property
+    def suit(self) -> Union[Suit, None]:
+        """Return the Suit of the lead card in the trick."""
+        if not self._start_suit and self._cards:
+            self._start_suit = self.cards[0].suit
         return self._start_suit
