@@ -5,21 +5,21 @@ from ..source.file_operations import load_rbn, save_pbn, load_pbn
 from ..source.card import Card
 
 DATA_PATH = 'test_data/'
-load_path = ''.join([DATA_PATH, 'pbn_input_file_1.pbn'])
-events_loaded = load_pbn(load_path)
+LOAD_PATH = ''.join([DATA_PATH, 'pbn_input_file_1.pbn'])
+events_loaded = load_pbn(LOAD_PATH)
 
 # Create a pbn file from a rbn input to test saves
-input_path = ''.join([DATA_PATH, 'rbn_input_file_1.rbn'])
-save_path = ''.join([DATA_PATH, 'pbn_output_file_1.pbn'])
-test_events = load_rbn(input_path)
-save_pbn(test_events, save_path)
-events_saved = load_pbn(save_path)
+INPUT_PATH = ''.join([DATA_PATH, 'rbn_input_file_1.rbn'])
+SAVE_PATH = ''.join([DATA_PATH, 'pbn_output_file_1.pbn'])
+rbn_events = load_rbn(INPUT_PATH)
+save_pbn(rbn_events, SAVE_PATH)
+events_saved = load_pbn(SAVE_PATH)
 
 
 def test_file_not_found():
     """Ensure file not found raises error."""
     with pytest.raises(FileNotFoundError):
-        test_events = load_rbn('invalid_path')
+        load_rbn('invalid_path')
 
 
 @pytest.mark.parametrize("events, expected", [
@@ -152,11 +152,26 @@ def test_pbn_board_declarer(board, expected):
 
 @pytest.mark.parametrize("board, expected", [
     (events_loaded[0].boards[3], "5H"),
-    (events_saved[0].boards[0], "")
 ])
 def test_pbn_board_contract(board, expected):
     """Ensure that the board is constructed correctly: contract."""
-    # assert board.contract.call.name == expected
+    assert board.contract.call.name == expected
+
+
+@pytest.mark.parametrize("board, expected", [
+    (events_loaded[0].boards[3], "D"),
+])
+def test_pbn_board_contract_doubled(board, expected):
+    """Ensure that the board is constructed correctly: contract."""
+    assert board.contract.modifier == expected
+
+
+@pytest.mark.parametrize("board, expected", [
+    (events_loaded[0].boards[12], "R"),
+])
+def test_pbn_board_contract_redoubled(board, expected):
+    """Ensure that the board is constructed correctly: contract."""
+    assert board.contract.modifier == expected
 
 
 def test_pbn_board_hands():
